<?php

/**
 * @file
 * Enables modules and site configuration for a standard site installation.
 */

use Drupal\contact\Entity\ContactForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Implements hook_form_FORM_ID_alter() for install_configure_form().
 *
 * Allows the profile to alter the site configuration form.
 */
function invi_profile_form_install_configure_form_alter(&$form, FormStateInterface $form_state): void {
  $site_name_df = 'INVI profile demo';
  $email_df = 'abc@gmail.com';
  $user_name_df = 'admin';

  $form['site_information']['site_name']['#default_value'] = $site_name_df;
  $form['site_information']['site_mail']['#default_value'] = $email_df;
  $form["admin_account"]["account"]["name"]['#default_value'] = $user_name_df;
  $form["admin_account"]["account"]["mail"]['#default_value'] = $email_df;
  $form["regional_settings"]["site_default_country"]['#default_value'] = 'VN';
  $form["regional_settings"]["date_default_timezone"]['#default_value'] = 'Asia/Ho_Chi_Minh';
  $form['#submit'][] = 'invi_profile_form_install_configure_submit';
}

/**
 * Submission handler to sync the contact.form.feedback recipient.
 */
function invi_profile_form_install_configure_submit($form, FormStateInterface $form_state): void {
  $site_mail = $form_state->getValue('site_mail');
  $password = $form_state->getValue('account')['pass'];
  invi_profile_set_users_passwords($password);
}

/**
 * Sets the password of admin to be the password for all users.
 */
function invi_profile_set_users_passwords($admin_password): void {
  // Collect the IDs of all users with roles editor or author.
  $ids = \Drupal::entityQuery('user')
    ->accessCheck(FALSE)
    ->condition('roles', ['author', 'editor'], 'IN')
    ->execute();

  $users = \Drupal::entityTypeManager()->getStorage('user')->loadMultiple($ids);
  foreach ($users as $user) {
    $user->setPassword($admin_password);
    $user->save();
  }
}
